#####################
### Preliminaries ###
#####################
# Installing the R-INLA package
install.packages("INLA", repos="https://www.math.ntnu.no/inla/R/stable")

# Loading INLA package
require(INLA)

########################################
### Fitting a simple model in R-INLA ###
########################################
# Loading the trees dataset
data(Seeds)

# Viewing the structure of the dataset
str(Seeds)

# Viewing the first six rows of Seeds
head(Seeds)

## Model with Fixed Effects

# Model formula
formula1 <- r ~ 1 + x1 + x2 + x1*x2

# Fitting the model in R-INLA
mod1 <- inla(formula1,
             data = Seeds,
             family = "binomial", 
             Ntrials = n,
             control.compute=list(dic=TRUE))

# Creating summary of the fitted model
summary(mod1)

## Model with fixed and random effects

# Model formula
formula2 <- r ~ 1 + x1 + x2 + x1*x2 + f(plate, model='iid')

# Fitting the model in R-INLA
mod2 <- inla(formula2,
             data = Seeds,
             family = "binomial", 
             Ntrials = n, 
             control.compute = list(dic=TRUE))

# Creating summary of the fitted model
summary(mod2)

##########################################
### Fitting smoothing models in R-INLA ###
##########################################
# Loading the trees dataset
data(trees)

# Viewing the structure of the dataset
str(trees)

# Viewing the first six rows of Seeds
head(trees)

# Model formula
formula3 <- logVolume ~ 1 + 
  f(Height, model="rw2") + # Smoothed function of Girth
  f(Girth, model="rw2")   # Smoothed function of Height

# Creating a log volume variable
trees$logVolume <- log(trees$Volume)

# Fitting the model in `R-INLA`
mod3 <- inla(formula3,
             data = trees,
             family = "normal", 
             control.compute = list(dic=TRUE))

# Creating summary of the fitted model
summary(mod3)
